@@ -152,13 +152,9 @@ static int snd_pcm_dsnoop_sync_ptr(snd_pcm_t *pcm)
 	old_slave_hw_ptr = dsnoop->slave_hw_ptr;
 	snoop_timestamp(pcm);
 	slave_hw_ptr = dsnoop->slave_hw_ptr;
-	diff = slave_hw_ptr - old_slave_hw_ptr;
+	diff = pcm_frame_diff(slave_hw_ptr, old_slave_hw_ptr, dsnoop->slave_boundary);
 	if (diff == 0)		/* fast path */
 		return 0;
-	if (diff < 0) {
-		slave_hw_ptr += dsnoop->slave_boundary;
-		diff = slave_hw_ptr - old_slave_hw_ptr;
-	}
 	snd_pcm_dsnoop_sync_area(pcm, old_slave_hw_ptr, diff);
 	dsnoop->hw_ptr += diff;
 	dsnoop->hw_ptr %= pcm->boundary;
