@@ -121,7 +121,8 @@ int tplg_parse_refs(snd_config_t *cfg, struct tplg_elem *elem,
 /* save references */
 int tplg_save_refs(snd_tplg_t *tplg ATTRIBUTE_UNUSED,
 		   struct tplg_elem *elem, unsigned int type,
-		   const char *id, char **dst, const char *pfx)
+		   const char *id, struct tplg_buf *dst,
+		   const char *pfx)
 {
 	struct tplg_ref *ref, *last;
 	struct list_head *pos;
@@ -890,7 +891,7 @@ err:
 /* save tuple set */
 static int tplg_save_tuple_set(struct tplg_vendor_tuples *tuples,
 			       unsigned int set_index,
-			       char **dst, const char *pfx)
+			       struct tplg_buf *dst, const char *pfx)
 {
 	struct tplg_tuple_set *set;
 	struct tplg_tuple *tuple;
@@ -929,6 +930,8 @@ static int tplg_save_tuple_set(struct tplg_vendor_tuples *tuples,
 			err = tplg_save_printf(dst, pfx, "\t'%s' ",
 					       tuple->token);
 		}
+		if (err < 0)
+			return err;
 		switch (set->type) {
 		case SND_SOC_TPLG_TUPLE_TYPE_UUID:
 			err = tplg_save_printf(dst, NULL, "'" UUID_FORMAT "'\n",
@@ -1014,7 +1017,7 @@ static int parse_tuple_sets(snd_config_t *cfg,
 /* save tuple sets */
 int tplg_save_tuple_sets(snd_tplg_t *tplg ATTRIBUTE_UNUSED,
 			 struct tplg_elem *elem,
-			 char **dst, const char *pfx)
+			 struct tplg_buf *dst, const char *pfx)
 {
 	struct tplg_vendor_tuples *tuples = elem->tuples;
 	unsigned int i;
@@ -1085,7 +1088,7 @@ int tplg_parse_tokens(snd_tplg_t *tplg, snd_config_t *cfg,
 /* save vendor tokens */
 int tplg_save_tokens(snd_tplg_t *tplg ATTRIBUTE_UNUSED,
 		     struct tplg_elem *elem,
-		     char **dst, const char *pfx)
+		     struct tplg_buf *dst, const char *pfx)
 {
 	struct tplg_vendor_tokens *tokens = elem->tokens;
 	unsigned int i;
@@ -1156,7 +1159,7 @@ int tplg_parse_tuples(snd_tplg_t *tplg, snd_config_t *cfg,
 /* save vendor tuples */
 int tplg_save_tuples(snd_tplg_t *tplg ATTRIBUTE_UNUSED,
 		     struct tplg_elem *elem,
-		     char **dst, const char *pfx)
+		     struct tplg_buf *dst, const char *pfx)
 {
 	char pfx2[16];
 	int err;
@@ -1242,7 +1245,7 @@ int tplg_parse_manifest_data(snd_tplg_t *tplg, snd_config_t *cfg,
 
 /* save manifest data */
 int tplg_save_manifest_data(snd_tplg_t *tplg ATTRIBUTE_UNUSED,
-			    struct tplg_elem *elem, char **dst,
+			    struct tplg_elem *elem, struct tplg_buf *dst,
 			    const char *pfx)
 {
 	struct list_head *pos;
@@ -1275,9 +1278,9 @@ int tplg_save_manifest_data(snd_tplg_t *tplg ATTRIBUTE_UNUSED,
 					       elem->id, index, ref->id);
 		} else {
 			err = tplg_save_printf(dst, pfx, "\t'%s'\n", ref->id);
-			if (err < 0)
-				return err;
 		}
+		if (err < 0)
+			return err;
 		index++;
 	}
 	if (count > 1) {
@@ -1420,7 +1423,7 @@ int tplg_parse_data(snd_tplg_t *tplg, snd_config_t *cfg,
 /* save data element */
 int tplg_save_data(snd_tplg_t *tplg ATTRIBUTE_UNUSED,
 		   struct tplg_elem *elem,
-		   char **dst, const char *pfx)
+		   struct tplg_buf *dst, const char *pfx)
 {
 	struct snd_soc_tplg_private *priv = elem->data;
 	struct list_head *pos;
@@ -1611,7 +1614,7 @@ int tplg_decode_manifest_data(snd_tplg_t *tplg,
 	if (!elem)
 		return -ENOMEM;
 
-	tplg_log(tplg, 'D', pos, "manifest: private size %d", size);
+	tplg_log(tplg, 'D', pos, "manifest: private size %zd", size);
 	return tplg_add_data(tplg, elem, bin, size);
 }
 
@@ -1671,7 +1674,7 @@ static int tplg_verify_tuple_set(snd_tplg_t *tplg, size_t pos,
 
 	va = bin;
 	if (size < sizeof(*va) || size < va->size) {
-		tplg_log(tplg, 'A', pos, "tuple set verify: wrong size %d", size);
+		tplg_log(tplg, 'A', pos, "tuple set verify: wrong size %zd", size);
 		return -EINVAL;
 	}
 
@@ -1718,7 +1721,7 @@ static int tplg_decode_tuple_set(snd_tplg_t *tplg,
 
 	va = bin;
 	if (size < sizeof(*va) || size < va->size) {
-		SNDERR("tuples: wrong size %d", size);
+		SNDERR("tuples: wrong size %zd", size);
 		return -EINVAL;
 	}
 
@@ -1805,14 +1808,14 @@ static int tplg_verify_tuples(snd_tplg_t *tplg, size_t pos,
 	int err;
 
 	if (size < sizeof(*va)) {
-		tplg_log(tplg, 'A', pos, "tuples: small size %d", size);
+		tplg_log(tplg, 'A', pos, "tuples: small size %zd", size);
 		return -EINVAL;
 	}
 
 next:
 	va = bin;
 	if (size < sizeof(*va)) {
-		tplg_log(tplg, 'A', pos, "tuples: unexpected vendor arry size %d", size);
+		tplg_log(tplg, 'A', pos, "tuples: unexpected vendor arry size %zd", size);
 		return -EINVAL;
 	}
 
@@ -1841,14 +1844,14 @@ static int tplg_decode_tuples(snd_tplg_t *tplg,
 	int err;
 
 	if (size < sizeof(*va)) {
-		SNDERR("tuples: small size %d", size);
+		SNDERR("tuples: small size %zd", size);
 		return -EINVAL;
 	}
 
 next:
 	va = bin;
 	if (size < sizeof(*va)) {
-		SNDERR("tuples: unexpected vendor arry size %d", size);
+		SNDERR("tuples: unexpected vendor arry size %zd", size);
 		return -EINVAL;
 	}
 
@@ -1893,7 +1896,7 @@ int tplg_add_data(snd_tplg_t *tplg,
 next:
 	tp = bin;
 	if (off + size < tp->size) {
-		SNDERR("data: unexpected element size %d", size);
+		SNDERR("data: unexpected element size %zd", size);
 		return -EINVAL;
 	}
 
